<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>État</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Fichier Autostatus</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n seconde</numerusform><numerusform>%n secondes</numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupé</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>État automatique</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>&amp;Autostatus</translation>
    </message>
</context>
</TS>